==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-tab-bar.dart <==
/*
Imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-tab-bar.dart';

Description:
Tab Bar  is implemented with a text and an icon and can accept multiple tabs.

Usage:
The user has to pass a list containing a text, an icon for the Tab Bar.
The text is a string type and icon is the Icon type data. The user can edit other constants from the constants file provided as per requirement.

 onTap(int s)
    {
      print(s);

    }
    List<TabBarList> tabs = [];
    TabBarList tab1 = new TabBarList(
        "menu", Icon(Icons.fastfood));
    TabBarList tab2 = new TabBarList(
        "cart", Icon(Icons.fastfood));

    tabs.add(tab1);
    tabs.add(tab2);

Object Call for the widget:
showTabBar(TabBarParameters(tablist: tabs),onTap),


Author:
Ishita Agrawal

*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' ;

import 'widget-classesUsed.dart';

Widget showTabBar(TabBarParameters param,void  Function(int)callback) {

  if (param == null && callback == null) {

    return DefaultTabController(
      length:3,
      child: new Scaffold(
        backgroundColor: MediumGreyThemeData().scaffoldBackgroundColor,
        appBar: new AppBar(
          backgroundColor: MediumGreyThemeData().scaffoldBackgroundColor,
          bottom: TabBar(
            labelColor: MediumGreyThemeData().focusColor,
            indicatorColor: MediumGreyThemeData().indicatorColor,
            unselectedLabelColor: MediumGreyThemeData().disabledColor,

            indicator: BoxDecoration(
              boxShadow: [
                BoxShadow(
                    color: MediumGreyThemeData().primaryColorLight,
                    offset: Offset(offset1, offset2))
              ],
              borderRadius: BorderRadius.circular(tab_border),
              border: Border.all(
                  color: MediumGreyThemeData().primaryColorLight,
                  width: tab_border_width),
              color: MediumGreyThemeData().primaryColorDark,
            ),
            tabs: [
              Tab(icon: Icon(Icons.directions_car)),
              Tab(icon: Icon(Icons.directions_transit)),
              Tab(icon: Icon(Icons.directions_bike)),
            ],
          ),
        ),
        
        
      ),
    );
  }
  else {
    List<Tab> tab = [];
    var tabs;

    for (var tabvar = 0; tabvar < param.tablist.length; tabvar++) {
      tabs = new Tab(
          text: param.tablist[tabvar].text,
          icon: param.tablist[tabvar].icons != null
              ? param.tablist[tabvar].icons
              : Icon(Icons.favorite));
      tab.add(tabs);
    }
    List<Widget> wid = [];


    if (
        param.borderRadius != null) {
      return DefaultTabController(
        length: param.tablist.length,
        child: new Scaffold(
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : MediumGreyThemeData().scaffoldBackgroundColor,
          appBar: new AppBar(
            backgroundColor: (param.backgroundColor != null)
                ? param.backgroundColor
                : MediumGreyThemeData().scaffoldBackgroundColor,
            bottom: TabBar(
              labelColor: (param.labelColor != null)
                  ? param.labelColor
                  : MediumGreyThemeData().focusColor,
              indicatorColor: (param.indicatorColor != null)
                  ? param.indicatorColor
                  : MediumGreyThemeData().indicatorColor,
              unselectedLabelColor: (param.unselectedLabelColor != null)
                  ? param.unselectedLabelColor
                  : MediumGreyThemeData().disabledColor,
              onTap: callback,
              indicator: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                      color: (param.boxShadowColor != null)
                          ? param.boxShadowColor
                          : MediumGreyThemeData().primaryColorLight,
                      offset: Offset(offset1, offset2))
                ],
                borderRadius: (param.borderRadius != null)
                    ? param.borderRadius
                    : BorderRadius.circular(tab_border),
                border: Border.all(
                    color: (param.borderColor != null)
                        ? param.borderColor
                        : MediumGreyThemeData().primaryColorLight,
                    width: (param.borderWidth != null)
                        ? param.borderWidth
                        : tab_border_width),
                color: (param.boxColor != null)
                    ? param.boxColor
                    : MediumGreyThemeData().primaryColorDark,
              ),
              tabs: tab,
            ),
          ),
          
        ),
      );
    } else {
      return DefaultTabController(
        length: param.tablist.length,
        child: new Scaffold(
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : MediumGreyThemeData().scaffoldBackgroundColor,
          appBar: new AppBar(
            backgroundColor: (param.backgroundColor != null)
                ? param.backgroundColor
                : MediumGreyThemeData().scaffoldBackgroundColor,
            bottom: TabBar(
              labelColor: (param.labelColor != null)
                  ? param.labelColor
                  : MediumGreyThemeData().focusColor,
              indicatorColor: (param.indicatorColor != null)
                  ? param.indicatorColor
                  : MediumGreyThemeData().indicatorColor,
              unselectedLabelColor: (param.unselectedLabelColor != null)
                  ? param.unselectedLabelColor
                  : MediumGreyThemeData().disabledColor,
              onTap: callback,
              indicator: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                      color: (param.boxShadowColor != null)
                          ? param.boxShadowColor
                          : MediumGreyThemeData().primaryColorLight,
                      offset: Offset(offset1, offset2))
                ],
                border: Border(
                  bottom: BorderSide(
                    color: (param.borderColor != null)
                        ? param.borderColor
                        : MediumGreyThemeData().focusColor,
                    width: (param.borderWidth != null)
                        ? param.borderWidth
                        : tab_underline_width,
                  ),
                ),
                color: (param.boxColor != null)
                    ? param.boxColor
                    : MediumGreyThemeData().primaryColorDark,
              ),
              tabs: tab,
            ),
          ),
          
        ),
      );
    }
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-tab-bar.dart <==
/*
Imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-tab-bar.dart';

Description:
Tab Bar  is implemented with a text and an icon and can accept multiple tabs.

Usage:
The user has to pass a list containing a text, an icon for the Tab Bar.
The text is a string type and icon is the Icon type data. The user can edit other constants from the constants file provided as per requirement.

 onTap(int s)
    {
      print(s);

    }
    List<TabBarList> tabs = [];
    TabBarList tab1 = new TabBarList(
        "menu", Icon(Icons.fastfood));
    TabBarList tab2 = new TabBarList(
        "cart", Icon(Icons.fastfood));

    tabs.add(tab1);
    tabs.add(tab2);

Object Call for the widget:
showTabBar(TabBarParameters(tablist: tabs),onTap),


Author:
Ishita Agrawal

*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' ;


Widget showTabBar(TabBarParameters param,void  Function(int)callback) {

  if (param == null && callback == null) {

    return DefaultTabController(
      length:3,
      child: new Scaffold(
        backgroundColor: mediumGreyThemeData().scaffoldBackgroundColor,
        appBar: new AppBar(
          backgroundColor: mediumGreyThemeData().scaffoldBackgroundColor,
          bottom: TabBar(
            labelColor: mediumGreyThemeData().focusColor,
            indicatorColor: mediumGreyThemeData().indicatorColor,
            unselectedLabelColor: mediumGreyThemeData().disabledColor,

            indicator: BoxDecoration(
              boxShadow: [
                BoxShadow(
                    color: mediumGreyThemeData().primaryColorLight,
                    offset: Offset(offset1, offset2))
              ],
              borderRadius: BorderRadius.circular(tab_border),
              border: Border.all(
                  color: mediumGreyThemeData().primaryColorLight,
                  width: tab_border_width),
              color: mediumGreyThemeData().primaryColorDark,
            ),
            tabs: [
              Tab(icon: Icon(Icons.directions_car)),
              Tab(icon: Icon(Icons.directions_transit)),
              Tab(icon: Icon(Icons.directions_bike)),
            ],
          ),
        ),
        
        
      ),
    );
  }
  else {
    List<Tab> tab = [];
    var tabs;

    for (var tabvar = 0; tabvar < param.tablist.length; tabvar++) {
      tabs = new Tab(
          text: param.tablist[tabvar].text,
          icon: param.tablist[tabvar].icons != null
              ? param.tablist[tabvar].icons
              : Icon(Icons.favorite));
      tab.add(tabs);
    }
   // List<Widget> wid = [];


    if (
        param.borderRadius != null) {
      return DefaultTabController(
        length: param.tablist.length,
        child: new Scaffold(
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : mediumGreyThemeData().scaffoldBackgroundColor,
          appBar: new AppBar(
            backgroundColor: (param.backgroundColor != null)
                ? param.backgroundColor
                : mediumGreyThemeData().scaffoldBackgroundColor,
            bottom: TabBar(
              labelColor: (param.labelColor != null)
                  ? param.labelColor
                  : mediumGreyThemeData().focusColor,
              indicatorColor: (param.indicatorColor != null)
                  ? param.indicatorColor
                  : mediumGreyThemeData().indicatorColor,
              unselectedLabelColor: (param.unselectedLabelColor != null)
                  ? param.unselectedLabelColor
                  : mediumGreyThemeData().disabledColor,
              onTap: callback,
              indicator: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                      color: (param.boxShadowColor != null)
                          ? param.boxShadowColor
                          : mediumGreyThemeData().primaryColorLight,
                      offset: Offset(offset1, offset2))
                ],
                borderRadius: (param.borderRadius != null)
                    ? param.borderRadius
                    : BorderRadius.circular(tab_border),
                border: Border.all(
                    color: (param.borderColor != null)
                        ? param.borderColor
                        : mediumGreyThemeData().primaryColorLight,
                    width: (param.borderWidth != null)
                        ? param.borderWidth
                        : tab_border_width),
                color: (param.boxColor != null)
                    ? param.boxColor
                    : mediumGreyThemeData().primaryColorDark,
              ),
              tabs: tab,
            ),
          ),
          
        ),
      );
    } else {
      return DefaultTabController(
        length: param.tablist.length,
        child: new Scaffold(
          backgroundColor: (param.backgroundColor != null)
              ? param.backgroundColor
              : mediumGreyThemeData().scaffoldBackgroundColor,
          appBar: new AppBar(
            backgroundColor: (param.backgroundColor != null)
                ? param.backgroundColor
                : mediumGreyThemeData().scaffoldBackgroundColor,
            bottom: TabBar(
              labelColor: (param.labelColor != null)
                  ? param.labelColor
                  : mediumGreyThemeData().focusColor,
              indicatorColor: (param.indicatorColor != null)
                  ? param.indicatorColor
                  : mediumGreyThemeData().indicatorColor,
              unselectedLabelColor: (param.unselectedLabelColor != null)
                  ? param.unselectedLabelColor
                  : mediumGreyThemeData().disabledColor,
              onTap: callback,
              indicator: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                      color: (param.boxShadowColor != null)
                          ? param.boxShadowColor
                          : mediumGreyThemeData().primaryColorLight,
                      offset: Offset(offset1, offset2))
                ],
                border: Border(
                  bottom: BorderSide(
                    color: (param.borderColor != null)
                        ? param.borderColor
                        : mediumGreyThemeData().focusColor,
                    width: (param.borderWidth != null)
                        ? param.borderWidth
                        : tab_underline_width,
                  ),
                ),
                color: (param.boxColor != null)
                    ? param.boxColor
                    : mediumGreyThemeData().primaryColorDark,
              ),
              tabs: tab,
            ),
          ),
          
        ),
      );
    }
  }
}
